<?php


namespace FiloBlu\ExtInventory\Helper;

use Magento\Framework\App\Helper\AbstractHelper;
use Magento\InventorySalesApi\Api\Data\SalesChannelInterface;
use Magento\Store\Model\ScopeInterface;
use Magento\InventorySalesApi\Api\IsProductSalableInterface;

class Data extends AbstractHelper
{
    protected $context;
    protected $isProductSalableForRequestedQty;
    protected $isProductSalableInterface;
    protected $stockResolver;
    protected $_productRepository;
    protected $_websiteCollectionFactory;

    public function __construct(
        \Magento\Framework\App\Helper\Context $context,
        IsProductSalableInterface $isProductSalableInterface,
        \Magento\InventorySalesApi\Api\StockResolverInterface $stockResolver,
        \Magento\Store\Model\ResourceModel\Website\CollectionFactory $websiteCollectionFactory,
        \Magento\Catalog\Model\ProductRepository $productRepository
    ) {
        parent::__construct($context);
        $this->isProductSalableInterface = $isProductSalableInterface;
        $this->stockResolver = $stockResolver;
        $this->_websiteCollectionFactory = $websiteCollectionFactory;
        $this->_productRepository = $productRepository;
    }

    public function isEnabled()
    {
        return true;
    }

    public function isSalable($productSku, $websiteId){
        //$product = $this->getProductById($productId);
        $website_code = $this->getWebsiteCodeById($websiteId);
        $stock_id = $this->getStockIdByWebsiteCode($website_code);

        if(is_object($productSku)){
            $productSku = $productSku->getSku();
        }

        $isSalable = $this->isProductSalableInterface->execute($productSku, $stock_id);
        return $isSalable;
    }

    public function getWebsiteCodeById($websiteId)
    {
        $collection = $this->_websiteCollectionFactory->create();
        $collection->addFieldToFilter('website_id', array('eq' => $websiteId));
        $websiteData = $collection->getData();
        $websiteCode = $websiteData[0]['code'];
        return $websiteCode;
    }

    public function getStockIdByWebsiteCode($website_code){
        $stock = $this->stockResolver->execute(SalesChannelInterface::TYPE_WEBSITE,$website_code);
        return $stock->getStockId();
    }

    public function getProductById($id)
    {
        return $this->_productRepository->getById($id);
    }

    public function getProductBySku($sku)
    {
        return $this->_productRepository->get($sku);
    }





}