<?php

namespace FiloBlu\ExtInventory\Plugin\InventoryConfigurationApi\GetStockItemConfiguration;

use Exception;
use Magento\Framework\App\ResourceConnection;
use Magento\InventoryConfigurationApi\Api\Data\StockItemConfigurationInterface;
use Magento\InventoryConfigurationApi\Api\GetStockItemConfigurationInterface;

/**
 * Class LoadIsInStockPlugin
 * @package FiloBlu\ExtInventory\Plugin\InventoryConfigurationApi\GetStockItemConfiguration
 */
class LoadIsInStockPlugin
{
    /**
     * @var ResourceConnection
     */
    protected $resourceConnection;

    /**
     * LoadIsInStockPlugin constructor.
     * @param ResourceConnection $resourceConnection
     */
    public function __construct(ResourceConnection $resourceConnection)
    {
        $this->resourceConnection = $resourceConnection;
    }

    /**
     * @param GetStockItemConfigurationInterface $subject
     * @param StockItemConfigurationInterface $result
     * @param string $sku
     * @param int $stockId
     * @return StockItemConfigurationInterface
     * @SuppressWarnings(PHPMD.UnusedFormalParameter)
     */
    public function afterExecute(
        GetStockItemConfigurationInterface $subject,
        StockItemConfigurationInterface $result,
        string $sku,
        int $stockId
    ): StockItemConfigurationInterface
    {
        try {
            $row = $this->resourceConnection->getConnection()->fetchRow(
                "SELECT SUM(isi.quantity) AS quantity, SUM(isi.status) AS stock_status, issl.stock_id
FROM
    inventory_source_stock_link issl
INNER JOIN inventory_source_item isi ON
    issl.source_code = isi.source_code AND issl.stock_id = :stockId AND sku = :sku", ['stockId' => $stockId, 'sku' => $sku]

            );

            if ($row['stock_status'] === null) {
                return $result;
            }
            $extensionAttributes = $result->getExtensionAttributes();
            $extensionAttributes->setIsInStock($row['stock_status'] > 0);
            $result->setExtensionAttributes($extensionAttributes);
        } catch (Exception $e) {
            return $result;
        }
        return $result;
    }
}